
import inputCheck from './input-check';
import xhtml from '../xhtml/index';
import { errorinfo } from './validate';

export default {

    // options后续可以添加自定义规则
    // 目前先不支持

    install: function (Vue, options) {

        Vue.directive('inputCheck', {

            bind: function (el, binding) {
                window.setTimeout(function () {
                    inputCheck(el, binding);
                }, 100);
            },

            update: function (el, binding) {
                window.setTimeout(function () {
                    inputCheck(el, binding);
                }, 100);
            }

        });

        /**
         * 表单校验结果获取
         * -------------------------
         *
         * 使用方法：
         *
         * // 获取当前组件内（可包括子组件）form表单校验管理者
         * let formError=this.$error(formnode);
         *
         * // 方法一：判断表单是否合法
         * formError.isValiadte();
         *
         * // 方法二：如果非法，获取第一个非法信息
         * let first_error=formError.first();
         * 返回的数据格式为：
         * {
         *  "$el":错误的输入框结点
         * "$error":当前输入框的第一个错误提示信息
         * }
         *
         * // 方法三：获取错误信息
         * let error=formError.getError(target);
         */
        Vue.prototype.$error = function (formnode) {

            // 如果表单查找不到，报错，以免后续使用报错不容易捕获
            if (!xhtml.isNode(formnode)) throw new Error('Target is empty!');

            else {


                return {
                    // 返回boolean,true：表单合法，false:表单非法
                    "isValiadte": function () {
                        return !xhtml.hasClass(formnode, 'v-invalid');
                    },

                    // 获取第一个错误的输入框信息
                    "first": function () {
                        let nodes = formnode.getElementsByTagName('*'),
                            target;

                        // 筛选出来第一个非法输入
                        for (let i = 0; i < nodes.length; i++) {
                            if (xhtml.hasClass(nodes[i], 'v-invalid')) {
                                target = nodes[i];
                                break;
                            }
                        }

                        return this.getError(target);
                    },

                    // 获取指定输入框的错误信息
                    "getError": function (target) {

                        if (!xhtml.hasClass(target, "v-invalid")) {
                            return null;
                        }

                        // 记录输入的class
                        let input_class = " " + target.getAttribute('class') + " ";

                        let inputName = target.getAttribute('name');

                        // 设置默认的未自定义错误提示方式的默认提示
                        let error = inputName + "输入非法！";

                        // 寻找第一个类型的错误
                        for (let i = 0; i < errorinfo.length; i++) {
                            if (new RegExp(" v-invalid-" + errorinfo[i][0] + " ").test(input_class)) {

                                // 调用自定义错误提示确定提示文字
                                error = errorinfo[i][1](target, inputName);
                                break;
                            }
                        }

                        return {
                            "$el": target,
                            "$error": error
                        };

                    }
                };
            }

        };

    }
};
